@@ -103,13 +103,13 @@ var NAVTREEINDEX =
 "annotated.html",
 "core_8h.html#a02b3e6ff573afd1efba25efc8bbb2538",
 "global_8c.html#a457beceeca2fc2e7907289e766a0da13",
-"impl-module_8h.html#a0228a5d6fa88526e9072c4194ce9ad04",
-"keys_8h.html#adaf914599e9ddeab31f925204323f678",
-"page_proxy.html#sec_page_proxy_bind",
-"stream_8c.html#a0d2ad73d654de2bc11afe6847474afcb",
-"structpw__core__events.html#a6cf547297486e97c8969a1e08d837955",
-"structpw__node__methods.html#a66986c115ef6b4046c22774ea438a3ad",
-"utils_8h.html#a8869815cdd42998571019730afd248ff"
+"impl-module_8c.html#a85aaddad8033ae307b8be80052a930f0",
+"keys_8h.html#ad7fe1ca68b65df33c09b8d14cfd708b0",
+"page_node.html",
+"resource_8h.html#ae32b47d6f25f56678385b0c269e8c3e0",
+"structpw__control__events.html#a4e2a4c85f61336fb837a43c931b7c5fa",
+"structpw__node__info.html#ae3b1789c08bcae95888e042790c95b75",
+"unionpw__map__item.html#a51685fc6de470af5d8a477bc98de5bb2"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
