@@ -1,5 +1,11 @@
 var NAVTREEINDEX6 =
 {
+"resource_8h.html#ae32b47d6f25f56678385b0c269e8c3e0":[11,0,62,21],
+"resource_8h.html#af3044f96f645e97035b87d3b37d3e017":[11,0,62,24],
+"resource_8h.html#af8fe4859dd6826d5eb6c7e28f5519215":[11,0,62,13],
+"resource_8h_source.html":[11,0,62],
+"stream_8c.html":[11,0,63],
+"stream_8c.html#a0aa398ef7b09697a0e48719b27112614":[11,0,63,28],
 "stream_8c.html#a0d2ad73d654de2bc11afe6847474afcb":[11,0,63,35],
 "stream_8c.html#a1676b48e222d9bcf50fd21374ea121c2":[11,0,63,7],
 "stream_8c.html#a1f024c54b2e507824ea0f5441f5b2af4":[11,0,63,33],
@@ -114,9 +120,9 @@ var NAVTREEINDEX6 =
 "structhandle.html":[10,0,5],
 "structhandle.html#a5ab45bc1d6b1241a2bfde3b297579087":[10,0,5,3],
 "structhandle.html#a767c770296740f81b64b215a2b164e25":[10,0,5,2],
-"structhandle.html#a9cbc371814ac7ae4be0a4a5bcaf2aba4":[10,0,5,0],
+"structhandle.html#a9cbc371814ac7ae4be0a4a5bcaf2aba4":[10,0,5,1],
 "structhandle.html#ab5ff56d8bdb0a9de5c998515c4021fbc":[10,0,5,4],
-"structhandle.html#aff4be9c1d70007974cdb9c13c04dd0ac":[10,0,5,1],
+"structhandle.html#ad6b9b2f141cf500ccd3df916da9a0a3a":[10,0,5,0],
 "structimpl.html":[10,0,6],
 "structimpl.html#a1fbd22bf7a25dba52ebfb4fde6354f74":[10,0,6,2],
 "structimpl.html#a485c133db4c8c2a7764aa6d6a80ed2c9":[10,0,6,1],
@@ -243,11 +249,5 @@ var NAVTREEINDEX6 =
 "structpw__context__events.html#af3303a7f003c10bfbb454c0bbd13360c":[10,0,24,0],
 "structpw__control__events.html":[10,0,26],
 "structpw__control__events.html#a2cda9616fd4aa65d7cc2f8dc6efe69dc":[10,0,26,3],
-"structpw__control__events.html#a4d456606837f25ad3e55471ae23c6bdc":[10,0,26,4],
-"structpw__control__events.html#a4e2a4c85f61336fb837a43c931b7c5fa":[10,0,26,1],
-"structpw__control__events.html#ad23091c8931adf9aa85564b31e2d9ca8":[10,0,26,0],
-"structpw__control__events.html#adbd47ebc650888ca6235b763fa3f6ef2":[10,0,26,2],
-"structpw__core__events.html":[10,0,27],
-"structpw__core__events.html#a55c28400675736b9365e711884f7a73b":[10,0,27,3],
-"structpw__core__events.html#a61cdc8ed8d593d66bdd7702d8294c063":[10,0,27,7]
+"structpw__control__events.html#a4d456606837f25ad3e55471ae23c6bdc":[10,0,26,4]
 };
