@@ -1,5 +1,11 @@
 var NAVTREEINDEX8 =
 {
+"structpw__node__info.html#ae3b1789c08bcae95888e042790c95b75":[10,0,79,5],
+"structpw__node__methods.html":[10,0,80],
+"structpw__node__methods.html#a01dbc165d13370efdb6a54a5c3f40f41":[10,0,80,0],
+"structpw__node__methods.html#a0fee61facfa842f9be5b55815d78f49a":[10,0,80,3],
+"structpw__node__methods.html#a1f28beb1b607ebd270f2e06b4f9a5266":[10,0,80,1],
+"structpw__node__methods.html#a44bb3efe45f8a5c763cc62daaa099569":[10,0,80,5],
 "structpw__node__methods.html#a66986c115ef6b4046c22774ea438a3ad":[10,0,80,4],
 "structpw__node__methods.html#a9f04049f6b62d408dacdefe1aafcc802":[10,0,80,2],
 "structpw__permission.html":[10,0,81],
@@ -243,11 +249,5 @@ var NAVTREEINDEX8 =
 "type_8h.html#abd2e0accb96cd8359530ef6dc275187f":[11,0,67,2],
 "type_8h.html#ac0ee38218f80b11ad0586f7c30a1fc2f":[11,0,67,3],
 "type_8h_source.html":[11,0,67],
-"unionpw__map__item.html":[10,0,69],
-"unionpw__map__item.html#a51685fc6de470af5d8a477bc98de5bb2":[10,0,69,1],
-"unionpw__map__item.html#a5ab66a0f62ff9e5b8d6192f980658d38":[10,0,69,0],
-"utils_8c.html":[11,0,68],
-"utils_8h.html":[11,0,69],
-"utils_8h.html#a51cdf13519f0f57157c2278193d52052":[11,0,69,4],
-"utils_8h.html#a80e0ca15ccef3f20ef9524a26d8c2b45":[11,0,69,1]
+"unionpw__map__item.html":[10,0,69]
 };
